@@ -26,7 +26,6 @@ class ImageSpace(object):
         vox_size: array of voxel size in each dimension 
         vox2world: 4x4 affine to transform voxel coords -> world
         world2vox: inverse of above 
-        self.offset: private variable used for derived spaces 
     """
 
     def __init__(self, img):
@@ -40,7 +39,7 @@ class ImageSpace(object):
                 img = img.nibImage
             fname = img.get_filename()
 
-        self.file_name = fname     
+        self.fname = fname     
         self.size = np.array(img.shape[:3], np.int16)
         self.vox2world = img.affine
         self.header = img.header
@@ -53,8 +52,7 @@ class ImageSpace(object):
         spc = cls.__new__(cls)
         spc.vox2world = vox2world
         spc.size = np.array(size, np.int16)
-        spc._offset = None 
-        spc.file_name = None 
+        spc.fname = None 
         spc.header = None 
         return spc 
 
@@ -166,6 +164,14 @@ class ImageSpace(object):
         return vox2FSL
 
 
+    @property
+    def file_name(self):
+        if self.fname is not None: 
+            return self.fname
+        else: 
+            return "<ImageSpace not created from file path>"
+
+
     @property
     def FSL2vox(self):
         """Transformation from FSL scaled coordinates to voxels"""
@@ -202,7 +208,8 @@ class ImageSpace(object):
         else: 
             rounder = np.ceil 
       
-        if isinstance(factor, (int, float)):
+        factor = np.array(factor)
+        if factor.size == 1:
             factor = factor * np.ones(3)
 
         new_size = rounder(self.size / factor).astype(np.int16)
@@ -250,7 +257,7 @@ class ImageSpace(object):
         new_orig = self.vox2world[0:3,3] + (self.vox2world[0:3,0:3] @ start) 
         new.vox2world[0:3,3] = new_orig
         new.size = new_size 
-        new.file_name = None 
+        new.fname = None 
         return new 
 
 
@@ -338,7 +345,7 @@ class ImageSpace(object):
 
         new_spc = copy.deepcopy(self)
         new_spc.vox2world = reg @ new_spc.vox2world
-        new_spc.file_name = None 
+        new_spc.fname = None 
         return new_spc
 
 
@@ -353,17 +360,10 @@ class ImageSpace(object):
                 vox2world:     {self.vox2world[0,:]}
                                {self.vox2world[1,:]}
                                {self.vox2world[2,:]}
-                               {self.vox2world[3,:]}""")
+                               {self.vox2world[3,:]}
+                loaded from:   {self.file_name}""")
 
-        if self.file_name: 
-            text += f"""
-                loaded from: {self.file_name}"""
-        else: 
-            text += f"""
-                loaded from: (no direct file counterpart)"""
-        return textwrap.dedent(text)
 
-    
     def __eq__(self, other):
 
         f1 = np.allclose(self.vox2world, other.vox2world)
